@@ -1,11 +1,11 @@
 pub use crate::circuit::*;
-pub use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 pub use crate::pyo3;
 pub use crate::rearrange_spec::*;
 pub use crate::rrfs::*;
-pub use crate::smallvec::Sv;
 pub use crate::tensor_util::*;
 pub use crate::uuid::uuid;
 pub use crate::*;
+pub use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+pub use smallvec::SmallVec as Sv;
 pub use std::iter::zip;
 pub use uuid::Uuid;
