@@ -1,8 +1,5 @@
-use crate::{
-    all_imports::OpSize,
-    circuit::EinsumAxes,
-    hashmaps::{AHashSet as HashSet, FxHashMap as HashMap},
-};
+use crate::{all_imports::OpSize, circuit::EinsumAxes};
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use std::{
     collections::hash_map::Entry::{self, Vacant},
     iter::zip,
@@ -100,8 +97,8 @@ pub fn add_elim_zeros(add: &Add) -> Option<Add> {
 
 #[pyfunction]
 pub fn add_deduplicate(add: &Add) -> Option<Add> {
-    let mut duplicate_counts: HashMap<HashBytes, i32> = HashMap::new();
-    let mut hash_to_node: HashMap<HashBytes, CircuitRc> = HashMap::new();
+    let mut duplicate_counts: HashMap<HashBytes, i32> = HashMap::default();
+    let mut hash_to_node: HashMap<HashBytes, CircuitRc> = HashMap::default();
     for node in add.nodes.iter() {
         *duplicate_counts.entry(node.info().hash).or_insert(0) += 1;
         hash_to_node.insert(node.info().hash, node.clone());
@@ -136,7 +133,7 @@ pub fn remove_add_few_input(add: &Add) -> Option<CircuitRc> {
 }
 
 pub fn make_einsum_ints_same_one_layer(einsum: &Einsum) -> Einsum {
-    let mut top_int_map: HashMap<u8, u8> = HashMap::new();
+    let mut top_int_map: HashMap<u8, u8> = HashMap::default();
     let mut next_global_int: u8 = 0;
     for i in einsum.axes_in_input() {
         if let Vacant(e) = top_int_map.entry(i) {
@@ -151,7 +148,7 @@ pub fn make_einsum_ints_same_one_layer(einsum: &Einsum) -> Einsum {
         .iter()
         .map(|(node, ints)| match &*node.0 {
             Circuit::Einsum(einsum) => {
-                let mut bottom_int_map: HashMap<u8, u8> = HashMap::new();
+                let mut bottom_int_map: HashMap<u8, u8> = HashMap::default();
 
                 for (bottom_int, top_int) in zip(&einsum.out_axes, ints) {
                     if !bottom_int_map.contains_key(bottom_int) {
@@ -541,7 +538,7 @@ pub fn get_removable_axes(circuit: &CircuitRc) -> HashSet<usize> {
             .iter()
             .copied()
             .collect(),
-        _ => HashSet::new(),
+        _ => HashSet::default(),
     }
 }
 
@@ -989,12 +986,12 @@ pub fn einsum_merge_scalars(einsum: &Einsum) -> Option<Einsum> {
 #[pyfunction]
 pub fn einsum_concat_to_add(einsum: &Einsum) -> Option<Add> {
     // Which nodes contain a given einsum int, e.g. "ab,ab->" will produce {0: [0, 1], 1: [0, 1]}
-    let mut nodes_by_einsum_dim = HashMap::new();
+    let mut nodes_by_einsum_dim = HashMap::default();
     for (concat_idx, (_circ, einsum_ints)) in einsum.args.iter().enumerate() {
         for einsum_int in einsum_ints {
             nodes_by_einsum_dim
                 .entry(einsum_int)
-                .or_insert(HashSet::new())
+                .or_insert(HashSet::default())
                 .insert(concat_idx);
         }
     }
@@ -1259,7 +1256,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
             }
         }
         Circuit::Einsum(inner) => {
-            let mut int_indices: HashMap<u8, Option<TensorAxisIndex>> = HashMap::new();
+            let mut int_indices: HashMap<u8, Option<TensorAxisIndex>> = HashMap::default();
             for (idx, int) in zip(&node.index.0, &inner.out_axes) {
                 match int_indices.get(int) {
                     Some(_prev_idx) => {
@@ -1621,7 +1618,7 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
         return None;
     }
 
-    let mut hm: HashMap<Einsum, (f64, Option<String>)> = HashMap::new();
+    let mut hm: HashMap<Einsum, (f64, Option<String>)> = HashMap::default();
     for (einsum, scalar, name) in scalars_and_children {
         let (hm_val, hm_name) = hm.entry(einsum).or_insert((0.0, None));
         *hm_val += scalar;
