@@ -2,7 +2,8 @@ use super::{
     deep_map_op_context_preorder_stoppable, deep_map_preorder, deep_map_preorder_unwrap,
     prelude::*, visit_circuit, HashBytes,
 };
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+
 use crate::{pycall, pycallable};
 use macro_rules_attribute::apply;
 use pyo3::{pyfunction, PyObject, Python};
@@ -16,7 +17,7 @@ pub fn filter_nodes<F>(
 where
     F: Fn((circuit, CircuitRc)) -> Result<bool, _>,
 {
-    let mut result: HashSet<CircuitRc> = HashSet::new();
+    let mut result: HashSet<CircuitRc> = HashSet::default();
     visit_circuit(circuit, |circuit: CircuitRc| {
         if filter(circuit.clone())? {
             result.insert(circuit);
