@@ -1,12 +1,10 @@
 use crate::{
     all_imports::Shape,
     circuit::{print::repr_circuit_deep_compiler, repr::RustRepr},
-    hashmaps::FxHashMap as HashMap,
 };
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use std::io::prelude::*;
 
-use num_bigint::BigUint;
-
 use super::{
     canonicalize::deep_canonicalize,
     circuit_utils::has_leaf_symbols,
@@ -25,7 +23,9 @@ use super::{
 use crate::circuit::CircResult;
 use crate::opt_einsum::EinsumSpec;
 use crate::pyo3_prelude::*;
+use crate::python_println;
 use crate::{py_types::Tensor, timed, util::apply_fn_until_same};
+use num_bigint::BigUint;
 
 // a lot of the function boundries in this are there because it would be too hard to optimize things jointly
 // not because we don't need to optimize things jointly
@@ -251,13 +251,13 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
     );
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
     if context.settings.verbose >= 4 {
-        println!("Original Circuit");
+        python_println!("Original Circuit");
         circuit.compiler_print();
     }
     if context.settings.save_circ {
         let s = repr_circuit_deep_compiler(&circuit, true, true);
         let f_name = format!("cached_circ_{}.circ", circuit.info().hash_usize());
-        println!("Save circ to {}", f_name);
+        python_println!("Save circ to {}", f_name);
 
         let mut file = std::fs::File::create(f_name).unwrap();
         file.write_all(s.as_bytes()).unwrap();
@@ -276,7 +276,7 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
     let circuit = timed!(compiler_simp(circuit, context), 10, print_timings);
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
     if context.settings.verbose >= 3 {
-        println!("Simplified Circuit");
+        python_println!("Simplified Circuit");
         circuit.compiler_print();
     }
     let circuit = timed!(
@@ -290,7 +290,7 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
 
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
     if context.settings.verbose >= 3 {
-        println!("Distributed Circuit");
+        python_println!("Distributed Circuit");
         circuit.compiler_print();
     }
     let circuit = timed!(deep_heuristic_nest_adds(circuit), 10, print_timings);
@@ -300,7 +300,7 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
 
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
     if context.settings.verbose >= 3 {
-        println!("Final Circuit");
+        python_println!("Final Circuit");
         circuit.compiler_print();
     }
     circuit
@@ -314,10 +314,10 @@ pub fn optimize_to_schedule(
     let context = &mut OptimizationContext::new_settings_circuit(settings, circuit.clone());
     let verbose = settings.verbose;
     if verbose > 0 {
-        println!("Optimizing verbose {}", verbose)
+        python_println!("Optimizing verbose {}", verbose)
     }
     if settings.capture_and_print {
-        println!("{}", repr_circuit_deep_compiler(&**circuit, true, false));
+        python_println!("{}", repr_circuit_deep_compiler(&**circuit, true, false));
     }
     let optimized_circuit = timed!(optimize_circuit(circuit, context), 10, verbose >= 1);
     // return evaluate_fn(&*optimized_circuit).unwrap();
@@ -331,7 +331,7 @@ pub fn optimize_to_schedule(
         )?
     };
     if verbose > 1 {
-        println!("{}", schedule.get_stats());
+        python_println!("{}", schedule.get_stats());
     }
     Ok(schedule)
 }
