@@ -1,6 +1,6 @@
 use std::{collections::BTreeSet, iter::zip};
 
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 
 use crate::{
     opt_einsum::EinsumSpec,
@@ -78,7 +78,7 @@ pub fn count_nodes(circuit: CircuitRc) -> usize {
 }
 
 pub fn hash_to_node(circuit: CircuitRc) -> HashMap<HashBytes, CircuitRc> {
-    let mut result: HashMap<HashBytes, CircuitRc> = HashMap::new();
+    let mut result: HashMap<HashBytes, CircuitRc> = HashMap::default();
     visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         result.insert(x.info().hash, x.clone());
     });
@@ -86,7 +86,7 @@ pub fn hash_to_node(circuit: CircuitRc) -> HashMap<HashBytes, CircuitRc> {
 }
 
 pub fn subcircuits(circuit: CircuitRc) -> HashSet<CircuitRc> {
-    let mut result: HashSet<CircuitRc> = HashSet::new();
+    let mut result: HashSet<CircuitRc> = HashSet::default();
     visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         result.insert(x);
     });
@@ -170,7 +170,7 @@ pub fn get_all_einsum_specs(circuit: CircuitRc) -> Vec<EinsumSpec> {
 #[pyfunction]
 /// children first
 pub fn toposort_circuit(circuit: CircuitRc) -> Vec<CircuitRc> {
-    let mut num_refs: HashMap<CircuitRc, usize> = HashMap::new();
+    let mut num_refs: HashMap<CircuitRc, usize> = HashMap::default();
     visit_circuit_unwrap(circuit.clone(), |c| {
         for child in c.children() {
             *num_refs.entry(child).or_insert(0) += 1;
@@ -198,7 +198,7 @@ where
     F: FnMut(CircuitRc, Vec<T>) -> (CircuitRc, T),
 {
     let topo = toposort_circuit(circuit.clone());
-    let mut pass_ups: HashMap<CircuitRc, T> = HashMap::new();
+    let mut pass_ups: HashMap<CircuitRc, T> = HashMap::default();
     for c in topo {
         let passed_up = c.children().map(|c| pass_ups[&c].clone()).collect();
         let (new, pass_here) = f(c.clone(), passed_up);
@@ -217,7 +217,7 @@ where
 {
     let mut toposorted = toposort_circuit(circuit.clone());
     toposorted.reverse();
-    let mut passed_down: HashMap<CircuitRc, Vec<T>> = HashMap::new();
+    let mut passed_down: HashMap<CircuitRc, Vec<T>> = HashMap::default();
     for c in toposorted {
         let pass = pass_down(c.clone(), passed_down.get(&c).unwrap_or(&vec![]));
         for (child, pass) in zip(c.children(), pass) {
@@ -243,8 +243,8 @@ where
     F: Fn(CircuitRc, &T) -> Vec<T>,
     F2: Fn(CircuitRc, &T, &Vec<CircuitRc>) -> CircuitRc,
 {
-    let mut pass_down_cache: HashMap<(CircuitRc, T), Vec<T>> = HashMap::new();
-    let mut construct_cache: HashMap<(CircuitRc, T), CircuitRc> = HashMap::new();
+    let mut pass_down_cache: HashMap<(CircuitRc, T), Vec<T>> = HashMap::default();
+    let mut construct_cache: HashMap<(CircuitRc, T), CircuitRc> = HashMap::default();
 
     fn recurse<F, F2, T>(
         circuit: CircuitRc,
