@@ -1,15 +1,16 @@
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::py_types::{
     einops_repeat, einsum_py, make_diagonal_py, scalar_to_tensor, scalar_to_tensor_py, PY_UTILS,
 };
 use crate::pyo3_prelude::*;
-use crate::smallvec::Sv;
 use crate::sv;
 use crate::util::cumsum;
-use itertools::{zip, Itertools};
+use itertools::Itertools;
 use macro_rules_attribute::apply;
 use num_bigint::BigUint;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+use smallvec::SmallVec as Sv;
 use std::cmp::Ordering;
+use std::iter::zip;
 
 use super::{
     algebraic_rewrite::{add_deduplicate, add_flatten_once, remove_add_few_input},
@@ -157,7 +158,7 @@ impl Einsum {
     }
 
     pub fn shape_map(&self) -> Result<HashMap<AxisInt, usize>, CircuitConstructionError> {
-        let mut out = HashMap::new();
+        let mut out = HashMap::default();
         for (circ, axes) in &self.args {
             if circ.info().rank() != axes.len() {
                 return Err(CircuitConstructionError::EinsumLenShapeDifferentFromAxes {
@@ -589,7 +590,7 @@ impl Add {
     }
 
     pub fn to_counts(&self) -> HashMap<CircuitRc, usize> {
-        let mut counts = HashMap::new();
+        let mut counts = HashMap::default();
         for item in &self.nodes {
             *counts.entry(item.clone()).or_insert(0) += 1;
         }
