@@ -2,12 +2,11 @@ use super::{
     named_axes::set_named_axes, prelude::*, CachedCircuitInfo, PyCircuitBase, Shape,
     TensorEvalError,
 };
-use crate::hashmaps::FxHashMap as HashMap;
 use crate::lru_cache::TensorCacheRrfs;
 use crate::rrfs::{arrayconstant_from_hash, arrayconstant_from_hash_prefix, save_tensor_rrfs};
 use crate::{
     circuit_node_auto_impl, circuit_node_extra_impl,
-    py_types::{scalar_to_tensor, PyUuid, Tensor, PY_UTILS},
+    py_types::{scalar_to_tensor, Tensor, PY_UTILS},
     tensor_util::{TorchDeviceDtype, TorchDeviceDtypeOp},
 };
 use crate::{new_rc, pyo3_prelude::*, sv};
@@ -15,6 +14,7 @@ use base16::encode_lower;
 use macro_rules_attribute::apply;
 use num_bigint::BigUint;
 use pyo3::types::{IntoPyDict, PyTuple};
+use rustc_hash::FxHashMap as HashMap;
 use uuid::Uuid;
 
 use crate::circuit::NamedAxes;
@@ -134,8 +134,9 @@ impl ArrayConstant {
         device_dtype: TorchDeviceDtypeOp,
     ) -> Self {
         Python::with_gil(|py| {
-            let mut kwargs = HashMap::new();
+            let mut kwargs = HashMap::default();
             if let Some(dtype) = device_dtype.dtype {
+                let dtype: &str = &dtype;
                 kwargs.insert("dtype", PY_UTILS.torch.getattr(py, dtype).unwrap());
             }
             if let Some(device) = device_dtype.device {
@@ -211,6 +212,7 @@ impl ArrayConstant {
 #[pyclass(extends=PyCircuitBase, unsendable)]
 #[derive(Debug, Clone)]
 pub struct Symbol {
+    #[pyo3(get)]
     pub uuid: Uuid,
     info: CachedCircuitInfo,
     name: Option<String>,
@@ -268,14 +270,10 @@ impl Symbol {
 impl Symbol {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn py_new(shape: Shape, uuid: PyUuid, name: Option<String>) -> PyClassInitializer<Self> {
-        Symbol::new(shape, uuid.0, name).into_init()
+    fn py_new(shape: Shape, uuid: Uuid, name: Option<String>) -> PyClassInitializer<Self> {
+        Symbol::new(shape, uuid, name).into_init()
     }
 
-    #[getter]
-    fn uuid(&self) -> PyUuid {
-        PyUuid(self.uuid)
-    }
     #[staticmethod]
     pub fn new_with_random_uuid(shape: Shape, name: Option<String>) -> Self {
         Self::new(shape, Uuid::new_v4(), name)
@@ -365,6 +363,7 @@ impl ScalarConstant {
 
 #[test]
 fn test_nrc() {
+    pyo3::prepare_freethreaded_python();
     let ex = ScalarConstant::nrc(0.0, sv![1, 2], None);
     ex.compiler_print();
 }
