@@ -1,4 +1,4 @@
-use crate::hashmaps::FxHashMap as HashMap;
+use rustc_hash::FxHashMap as HashMap;
 use std::io::{Read, Write};
 
 use crate::circuit::circuit_optimizer::OptimizationContext;
@@ -102,7 +102,7 @@ pub fn randn_ablate_great_grandchildren(circ: CircuitRc) -> CircuitRc {
         .children()
         .flat_map(|child| child.children().collect::<Vec<_>>())
         .flat_map(|grandchild| grandchild.children().collect::<Vec<_>>());
-    let mut replacements: HashMap<HashBytes, CircuitRc> = HashMap::new();
+    let mut replacements: HashMap<HashBytes, CircuitRc> = HashMap::default();
     for great_grandchild in great_grandchildren {
         let ablated = Circuit::ArrayConstant(ArrayConstant::randn_seeded(
             great_grandchild.info().shape.clone(),
