@@ -6,10 +6,10 @@ use crate::circuit::{
     deep_map_op_context, generalfunction_merge_inverses,
     generalfunction_special_case_simplification,
 };
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::util::{apply_fn_until_none, apply_fn_until_same, mapping_until_end, AsOp};
 use crate::{pyo3_prelude::*, timed, timed_value};
 use num_bigint::BigUint;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 
 use super::nb_rewrites::{add_elim_removable_axes_weak, einsum_elim_removable_axes_weak};
 use super::visit_circuit_unwrap;
@@ -373,14 +373,14 @@ pub fn deep_push_down_index(circ: CircuitRc, min_size: Option<usize>) -> Circuit
 #[pyfunction]
 pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
     let circ = deep_canonicalize(circ, &mut Default::default());
-    let mut seen_adds: HashSet<Add> = HashSet::new();
+    let mut seen_adds: HashSet<Add> = HashSet::default();
     visit_circuit_unwrap(circ.clone(), |c: CircuitRc| {
         if let Some(add) = c.as_add() {
             seen_adds.insert(add.clone());
         }
     });
     // TODO: profile and optimize these
-    let mut intersections: HashSet<Add> = HashSet::new();
+    let mut intersections: HashSet<Add> = HashSet::default();
     for circ in &seen_adds {
         for circ2 in &seen_adds {
             let intersection = Add::new(
@@ -397,7 +397,7 @@ pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
         }
     }
     seen_adds.extend(intersections);
-    let mut mapping: HashMap<Add, Add> = HashMap::new();
+    let mut mapping: HashMap<Add, Add> = HashMap::default();
     while let Some((sup, new_sup)) = (|| {
         for cand_sub in &seen_adds {
             if cand_sub.nodes.len() >= 2 {
@@ -500,7 +500,7 @@ pub fn deep_optimize_einsums(circ: CircuitRc, context: &mut OptimizationContext)
             _ => None,
         },
         context,
-        &mut HashMap::new(),
+        &mut HashMap::default(),
     )
     .unwrap_or(circ)
 }
