@@ -1,6 +1,7 @@
 use itertools::Itertools;
 
-use crate::{hashmaps::AHashSet as HashSet, smallvec::Sv};
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+use smallvec::SmallVec as Sv;
 use std::iter::zip;
 
 use crate::{
