@@ -15,14 +15,13 @@ use super::{
 use crate::{
     circuit::{use_rust_comp, CircuitConstructionError, CircuitRc, HashBytes},
     eq_by_big_hash::EqByBigHash,
-    hashmaps::AHashSet as HashSet,
     impl_both_by_big_hash,
     pyo3_prelude::*,
     setup_callable,
     tensor_util::Slice,
     util::{as_sorted, flip_op_result, split_first_take, EmptySingleMany as ESM, IterInto},
 };
-
+use std::collections::HashSet;
 impl From<Matcher> for IterativeMatcher {
     fn from(x: Matcher) -> Self {
         IterativeMatcherData::Match(x).into()
@@ -380,7 +379,7 @@ impl IterativeMatcher {
             matchers
                 .into_iter()
                 .map(|x| ChainItem::new(Arc::new(x), Vec::new()))
-                .collect(),
+                .collect::<HashSet<_>>(),
         )
         .into()
     }
@@ -573,7 +572,7 @@ impl IterativeMatcher {
         IterativeMatcherData::Chains(
             [ChainItem::new(Arc::new(self.clone()), rest.into_collect())]
                 .into_iter()
-                .collect(),
+                .collect::<HashSet<_>>(),
         )
         .into()
     }
@@ -584,7 +583,7 @@ impl IterativeMatcher {
         IterativeMatcherData::Chains(
             rest.into_iter()
                 .map(|x| ChainItem::new(Arc::new(self.clone()), x.into_collect()))
-                .collect(),
+                .collect::<HashSet<_>>(),
         )
         .into()
     }
