@@ -24,12 +24,12 @@ use crate::{
         CircuitRc, CircuitType, HashBytes,
     },
     eq_by_big_hash::EqByBigHash,
-    hashmaps::AHashSet as HashSet,
     pyo3_prelude::*,
     setup_callable,
     tensor_util::Slice,
     util::{as_sorted, EmptySingleMany as ESM, IterInto},
 };
+use std::collections::HashSet;
 
 macro_rules! make_single_many {
     ($name:ident, $type:ty) => {
@@ -463,13 +463,13 @@ impl Matcher {
     #[staticmethod]
     #[args(types = "*")]
     pub fn types(types: Vec<CircuitType>) -> Self {
-        MatcherData::Type(types.into_iter().collect()).into()
+        MatcherData::Type(types.into_iter().collect::<HashSet<_>>()).into()
     }
 
     #[staticmethod]
     #[args(circuits = "*")]
     pub fn circuits(circuits: Vec<CircuitRc>) -> Self {
-        MatcherData::EqM(circuits.into_iter().collect()).into()
+        MatcherData::EqM(circuits.into_iter().collect::<HashSet<_>>()).into()
     }
 
     #[staticmethod]
