@@ -1,7 +1,6 @@
 #![allow(clippy::borrow_deref_ref)]
 use crate::all_imports::{RInnerInts, Sv, TensorInvariantError};
 use crate::circuit::circuit_utils::toposort_circuit;
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::pyo3_prelude::*;
 use crate::util::AxisInt;
 use crate::{
@@ -29,7 +28,9 @@ use num_bigint::BigUint;
 pub use parsing::{parse_compiler_repr_bijection, parse_compiler_repr_bijection_py};
 use py_circuit_items::circuit_rust_to_py;
 use pyo3::types::PyBytes;
+use pyo3::PyTypeInfo;
 use pyo3::{exceptions, pyclass::CompareOp};
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use std::collections::BTreeMap;
 use std::hash::Hash;
 use std::sync::Arc;
@@ -371,7 +372,7 @@ pub trait CircuitNode: CircuitNodeInit {
     where
         Self: Clone,
     {
-        println!("{}", self.compiler_repr())
+        crate::python_println!("{}", self.compiler_repr())
     }
 
     fn get_hash(&self) -> HashBytes {
@@ -582,7 +583,7 @@ macro_rules! define_circuit_union_impl {
 
             impl<'source> $crate::pyo3::FromPyObject<'source> for [<$name Type>] {
                 fn extract(inp: &'source $crate::pyo3::PyAny) -> $crate::pyo3::PyResult<Self> {
-                    use $crate::pyo3::{type_object::PyTypeObject, types::PyType};
+                    use $crate::pyo3::{ types::PyType};
 
                     let pairings: Vec<(Py<PyType>, [<$name Type>])> =
                         Python::with_gil(|py| vec![
@@ -606,7 +607,6 @@ macro_rules! define_circuit_union_impl {
 
             impl $crate::pyo3::IntoPy<$crate::pyo3::PyObject> for [<$name Type>] {
                 fn into_py(self, py: $crate::pyo3::Python<'_>) -> $crate::pyo3::PyObject {
-                    use crate::pyo3::{type_object::PyTypeObject};
                     match self {
                         $(
                             Self::$x => $x::type_object(py).into(),
@@ -1286,7 +1286,7 @@ pub enum CircuitConstructionError {
     #[error("Failed to construct equivalent explicitly computable circuit")]
     NoEquivalentExplicitlyComputable {},
 
-    #[error("python error {py_err:?}")]
+    #[error("python error {py_err}")]
     PythonError { py_err: Arc<PyErr> },
 
     #[error("just stopping iteration, not an actual error")]
@@ -1418,7 +1418,7 @@ where
     let mut toposorted = toposort_circuit(circuit);
     toposorted.reverse(); // its children first by default
 
-    let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::new();
+    let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::default();
     for (_i, sub) in toposorted.into_iter().enumerate() {
         f(sub.clone(), parents.get(&sub).unwrap_or(&vec![]));
         for child in sub.children() {
@@ -1434,7 +1434,7 @@ where
     let mut toposorted = toposort_circuit(circuit);
     toposorted.reverse(); // its children first by default
 
-    let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::new();
+    let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::default();
     for (_i, sub) in toposorted.into_iter().enumerate() {
         f(sub.clone(), parents.get(&sub).unwrap_or(&vec![]))?;
         for child in sub.children() {
@@ -1454,7 +1454,7 @@ where
     F: FnMut((circuit, CircuitRc)) -> Result<(), _>,
 {
     let mut f = f;
-    let mut seen: HashSet<HashBytes> = HashSet::new();
+    let mut seen: HashSet<HashBytes> = HashSet::default();
 
     fn recurse<F, CircuitConstructionError>(
         circ: CircuitRc,
@@ -1483,7 +1483,7 @@ pub fn visit_circuit_postorder<F>(circuit: CircuitRc, mut f: F)
 where
     F: FnMut(CircuitRc),
 {
-    let mut seen: HashSet<HashBytes> = HashSet::new();
+    let mut seen: HashSet<HashBytes> = HashSet::default();
 
     fn recurse<F>(circ: CircuitRc, seen: &mut HashSet<HashBytes>, f: &mut F)
     where
@@ -1875,7 +1875,7 @@ impl PyCircuitBase {
 
     #[args(bijection = "true", shape_only_necessary = "false")]
     fn compiler_print(&self, bijection: bool, shape_only_necessary: bool) {
-        println!("{}", self.compiler_repr(bijection, shape_only_necessary))
+        crate::python_println!("{}", self.compiler_repr(bijection, shape_only_necessary))
     }
 
     fn numel(&self) -> BigUint {
