@@ -1,6 +1,6 @@
 use crate::all_imports::{TensorAxisIndex, TensorIndex};
 use crate::circuit::deep_map_fallible_pre_new_children;
-use crate::hashmaps::FxHashMap as HashMap;
+use rustc_hash::FxHashMap as HashMap;
 
 use crate::{pycall, pyo3_prelude::*, sv};
 use once_cell::sync::Lazy;
@@ -415,7 +415,7 @@ impl ModuleNodeSpec {
         circuit: CircuitRc,
         name: Option<String>,
     ) -> Result<Self, CircuitConstructionError> {
-        let mut input_specs_dict: HashMap<usize, ModuleNodeArgSpec> = HashMap::new();
+        let mut input_specs_dict: HashMap<usize, ModuleNodeArgSpec> = HashMap::default();
         let circuit = deep_map_op_context(
             circuit.clone(),
             &|sub: CircuitRc, input_specs_dict: &mut HashMap<usize, ModuleNodeArgSpec>| {
@@ -736,7 +736,7 @@ pub fn inline_all_modules(circuit: CircuitRc) -> CircuitRc {
 use std::cell::RefCell;
 thread_local! {
     static MODULE_EXPANSIONS: RefCell<HashMap<(ModuleNodeSpec, Vec<HashBytes>), CircResult>> =
-        RefCell::new(HashMap::new());
+        RefCell::new(HashMap::default());
     static MODULE_EXPANSIONS_SHAPE: RefCell<HashMap<(ModuleNodeSpec, Vec<Shape>), CircResult>> =
-        RefCell::new(HashMap::new());
+        RefCell::new(HashMap::default());
 }
