@@ -1,5 +1,5 @@
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::util::is_unique;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use std::collections::BTreeMap;
 
 use uuid::Uuid;
@@ -120,8 +120,8 @@ pub fn get_axis_leaves(
         return Ok((
             name,
             circuit.clone(),
-            HashMap::from([(circuit, axis)]),
-            HashSet::new(),
+            HashMap::from_iter([(circuit, axis)]),
+            HashSet::default(),
         ));
     }
     let circ_named_axes =
@@ -129,7 +129,7 @@ pub fn get_axis_leaves(
     // circ_named_axes.compiler_print();
     let mut result_axis: HashMap<CircuitRc, usize> = Default::default();
     let mut result_no_axis: HashSet<CircuitRc> = Default::default();
-    let _names_to_remove = Some(HashSet::from([name.clone()]));
+    let _names_to_remove = Some(HashSet::from_iter([name.clone()]));
     visit_circuit_with_parents_fallible(circ_named_axes.clone(), |x, parents| {
         // println!("child");
         // x.compiler_print();
