@@ -12,14 +12,17 @@ macro_rules! new_rc {
 }
 #[macro_export]
 macro_rules! new_rc_unwrap {
-    ($pub:vis fn $fname:ident($( $arg:ident : $argtype:ty),* $(,)?) -> ($rettype:ty)  $body:expr)=>{
-        $pub fn $fname($($arg : $argtype),*)->$rettype {
+    ($pub:vis fn $fname:ident($( $arg:ident : $argtype:ty),* $(,)?) -> (Result<$rettype:ty,CircuitConstructionError>)  $body:expr)=>{
+        $pub fn $fname($($arg : $argtype),*)->Result<$rettype,CircuitConstructionError> {
             $body
         }
 
         pub fn nrc($($arg : $argtype),*)->CircuitRc{
             Self::$fname($($arg),*).unwrap().rc()
         }
+        pub fn new($($arg : $argtype),*)-> $rettype{
+            Self::$fname($($arg),*).unwrap()
+        }
     }
 }
 
