@@ -8,13 +8,13 @@ use crate::circuit::{
     AutoTag, CircResult, CircuitNode, Cumulant, DiscreteVar, ModuleNode, ModuleNodeSpec,
     StoredCumulantVar,
 };
-use crate::hashmaps::FxHashMap as HashMap;
 use crate::lru_cache::TensorCacheRrfs;
 use crate::py_types::Tensor;
 use crate::pyo3_prelude::*;
 use crate::tensor_util::TorchDeviceDtypeOp;
 use once_cell::sync::Lazy;
 use regex::Regex;
+use rustc_hash::FxHashMap as HashMap;
 use std::iter::zip;
 use std::str::FromStr;
 use std::sync::Arc;
@@ -22,8 +22,8 @@ use uuid::Uuid;
 
 #[pyfunction(
     string,
-    module_spec_map = "HashMap::new()",
-    reference_circuits = "HashMap::new()",
+    module_spec_map = "HashMap::default()",
+    reference_circuits = "HashMap::default()",
     tensors_as_random = "false",
     tensors_as_random_device_dtype = "TorchDeviceDtypeOp{device:None,dtype:None}",
     tensor_getter = "None"
@@ -371,7 +371,7 @@ pub fn parse_compiler_repr_bijection(
         }
         result
     }
-    let mut context: HashMap<usize, CircuitRc> = HashMap::new();
+    let mut context: HashMap<usize, CircuitRc> = HashMap::default();
     deep_convert_partial_circ(
         stack[0],
         &partial_circuits,
