@@ -1,4 +1,4 @@
-use crate::hashmaps::FxHashMap as HashMap;
+use rustc_hash::FxHashMap as HashMap;
 
 use super::{
     circuit_utils::{count_nodes, toposort_circuit, total_flops},
@@ -130,7 +130,7 @@ pub fn repr_circuit_deep_compiler(
     bijection: bool,
     shape_only_necessary: bool,
 ) -> String {
-    let mut seen_hashes: HashMap<HashBytes, String> = HashMap::new();
+    let mut seen_hashes: HashMap<HashBytes, String> = HashMap::default();
     fn recurse(
         circ: &Circuit,
         depth: usize,
