@@ -1,5 +1,5 @@
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use itertools::Itertools;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use smallvec::Array;
 use std::{collections::BTreeMap, fs::File, io::Write};
 use uuid::Uuid;
@@ -9,9 +9,10 @@ use super::{
     CircuitNode, OpSize, RearrangeSpec, TensorAxisIndex, TensorIndex,
 };
 use crate::{
-    all_imports::TorchDeviceDtypeOp, opt_einsum::EinsumSpec, rrfs::save_tensor_rrfs, smallvec::Sv,
+    all_imports::TorchDeviceDtypeOp, opt_einsum::EinsumSpec, rrfs::save_tensor_rrfs,
     tensor_util::Shape,
 };
+use smallvec::SmallVec as Sv;
 
 pub trait RustRepr {
     /// Serialize objects to Rust expression source code
