@@ -1,9 +1,3 @@
-use crate::{
-    hashmaps::{AHashSet as HashSet, FxHashMap as HashMap},
-    py_types::{scalar_to_tensor, tensor_scale, un_flat_concat, PY_UTILS},
-};
-use std::fmt::{self, Display};
-
 use super::{
     circuit_optimizer::{OptimizationContext, OptimizationSettings},
     circuit_utils::{hash_to_node, toposort_circuit},
@@ -17,6 +11,7 @@ use super::{
 };
 use crate::circuit::schedule_send::ScheduleToSend;
 use crate::lru_cache::TensorCacheRrfs;
+use crate::py_types::{scalar_to_tensor, tensor_scale, un_flat_concat, PY_UTILS};
 use crate::pyo3_prelude::*;
 use crate::util::filter_to_idx;
 use crate::{
@@ -35,6 +30,9 @@ use pyo3::{
     exceptions::PyException,
     types::{PyByteArray, PyBytes},
 };
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+use smallvec::SmallVec as Sv;
+use std::fmt::{self, Display};
 use thiserror::Error;
 
 #[derive(Clone, Debug)]
@@ -148,8 +146,8 @@ impl Schedule {
     pub fn get_stats(&self) -> ScheduleStats {
         let mut mem: BigUint = BigUint::from(0usize);
         let mut max_mem: BigUint = BigUint::from(0usize);
-        let mut biggest: HashMap<usize, CircuitRc> = HashMap::new();
-        let mut current: HashMap<usize, CircuitRc> = HashMap::new();
+        let mut biggest: HashMap<usize, CircuitRc> = HashMap::default();
+        let mut current: HashMap<usize, CircuitRc> = HashMap::default();
         for instruction in self.instructions.clone() {
             match instruction {
                 Instruction::Drop(drop) => {
@@ -602,7 +600,7 @@ pub fn order_to_schedule(
         output_circuit: None,
     };
 
-    let mut seen_dependencies: HashSet<usize> = HashSet::new();
+    let mut seen_dependencies: HashSet<usize> = HashSet::default();
     for ex in order.iter().rev() {
         for child in ex.children() {
             let next_id = circ_to_id.len();
@@ -781,7 +779,7 @@ fn simplify_dag_for_scheduling_and_kept_nodes(
     // and we need the maximum nodes on either side so the scheduler has the right bound
     // on intermediate memory consumption along the serial chain
     let chain_ends = dag.chains();
-    let mut nodes_to_prune: HashSet<usize> = HashSet::new();
+    let mut nodes_to_prune: HashSet<usize> = HashSet::default();
     for chain_end in chain_ends {
         // iterate backwards down the chain and accumulate the min and max on either side
         let c = &dag.node_costs;
@@ -827,7 +825,7 @@ fn subset_order_to_full_order(
     dag: &Dag,
 ) -> Vec<usize> {
     let mut result: Vec<usize> = vec![];
-    let mut result_set: HashSet<usize> = HashSet::new();
+    let mut result_set: HashSet<usize> = HashSet::default();
 
     fn recurse(orig_i: usize, result: &mut Vec<usize>, result_set: &mut HashSet<usize>, dag: &Dag) {
         if !result_set.contains(&orig_i) {
@@ -928,7 +926,7 @@ pub fn circuit_to_schedule(
             .iter()
             .filter_map(|x| x.1.as_scalar_constant().cloned())
             .collect(),
-        HashSet::from([circuit.info().hash]),
+        HashSet::from_iter([circuit.info().hash]),
         get_compatible_dtype(&circuit),
     );
     out.output_circuit = Some((kept_keys[0], circuit));
@@ -943,7 +941,7 @@ pub fn circuit_to_schedule_naive_toposort(circuit: CircuitRc) -> Schedule {
         &toposorted,
         &vec![],
         &vec![],
-        HashSet::from([circuit.info().hash]),
+        HashSet::from_iter([circuit.info().hash]),
         get_compatible_dtype(&circuit),
     );
     result.output_circuit = Some((kept_keys[0], circuit));
@@ -1009,7 +1007,7 @@ fn replace_module_schedules(schedule: &Schedule, context: &mut OptimizationConte
                             ),
                         ));
                     } else {
-                        let mut inner_to_outer_key: HashMap<usize, usize> = HashMap::from([(
+                        let mut inner_to_outer_key: HashMap<usize, usize> = HashMap::from_iter([(
                             inner_schedule.output_circuit.clone().unwrap().0,
                             *outermost_k,
                         )]);
