@@ -5,7 +5,6 @@ use super::{
     ScalarConstant, TensorEvalError,
 };
 use crate::new_rc_unwrap;
-use crate::py_types::PyUuid;
 use crate::{
     circuit::PyCircuitBase,
     circuit_node_auto_impl, circuit_node_extra_impl, new_rc,
@@ -31,6 +30,7 @@ use uuid::Uuid;
 pub struct AutoTag {
     #[pyo3(get)]
     pub node: CircuitRc,
+    #[pyo3(get)]
     pub uuid: Uuid,
     name: Option<String>,
     info: CachedCircuitInfo,
@@ -108,18 +108,13 @@ impl AutoTag {
     #[new]
     fn py_new(
         node: CircuitRc,
-        uuid: PyUuid,
+        uuid: Uuid,
         name: Option<String>,
     ) -> PyResult<PyClassInitializer<AutoTag>> {
-        let out = Self::new(node, uuid.0, name);
+        let out = Self::new(node, uuid, name);
         Ok(out.into_init())
     }
 
-    #[getter]
-    fn uuid(&self) -> PyUuid {
-        PyUuid(self.uuid)
-    }
-
     /// Creates a new AutoTag with a random UUID.
     #[staticmethod]
     pub fn new_with_random_uuid(node: CircuitRc, name: Option<String>) -> Self {
@@ -292,6 +287,7 @@ impl DiscreteVar {
 pub struct StoredCumulantVar {
     #[pyo3(get)]
     pub cumulants: BTreeMap<usize, CircuitRc>, // using btreemap so it always iterates in order
+    #[pyo3(get)]
     pub uuid: Uuid,
     name: Option<String>,
     info: CachedCircuitInfo,
@@ -456,28 +452,23 @@ impl StoredCumulantVar {
     #[new]
     fn py_new(
         cumulants: BTreeMap<usize, CircuitRc>,
-        uuid: Option<PyUuid>,
+        uuid: Option<Uuid>,
         name: Option<String>,
     ) -> PyResult<PyClassInitializer<StoredCumulantVar>> {
-        let uuid = uuid.unwrap_or_else(|| PyUuid(Uuid::new_v4()));
-        let out = Self::try_new(cumulants, uuid.0, name)?;
+        let uuid = uuid.unwrap_or_else(|| Uuid::new_v4());
+        let out = Self::try_new(cumulants, uuid, name)?;
         Ok(out.into_init())
     }
 
-    #[getter]
-    fn uuid(&self) -> PyUuid {
-        PyUuid(self.uuid)
-    }
-
     #[staticmethod]
     #[pyo3(name = "new_mv")]
     pub fn new_mv_py(
         mean: CircuitRc,
         variance: CircuitRc,
         higher_cumulants: BTreeMap<usize, CircuitRc>,
-        uuid: Option<PyUuid>,
+        uuid: Option<Uuid>,
         name: Option<String>,
     ) -> Result<Self, CircuitConstructionError> {
-        Self::new_mv(mean, variance, higher_cumulants, uuid.map(|x| x.0), name)
+        Self::new_mv(mean, variance, higher_cumulants, uuid, name)
     }
 }
