@@ -43,7 +43,6 @@ pub mod all_imports;
 mod caching;
 pub mod circuit;
 pub mod eq_by_big_hash;
-pub mod hashmaps;
 pub mod lazy;
 mod lru_cache;
 pub mod opt_einsum;
@@ -54,11 +53,21 @@ pub mod rearrange_spec;
 pub mod rrfs;
 mod server;
 pub mod set_cover;
-pub mod smallvec;
 pub mod tensor_util;
 mod union_find;
 pub mod util;
 
+#[macro_export]
+macro_rules! sv {
+    [$($tt:tt)*] => {
+        smallvec::smallvec!($($tt)*)
+    };
+}
+#[pyfunction]
+fn demo_panicing_function(x: circuit::CircuitRc) {
+    panic!();
+}
+
 /// A Python module implemented in Rust. The name of this function must match
 /// the `lib.name` setting in the `Cargo.toml`, else Python will not be able to
 /// import the module.
@@ -347,5 +356,6 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     )?)?;
 
     m.add_function(wrap_pyfunction!(circuit::print_circuit_type_check, m)?)?;
+    m.add_function(wrap_pyfunction!(demo_panicing_function, m)?)?;
     Ok(())
 }
