@@ -1,5 +1,4 @@
 use crate::circuit::{CircuitConstructionError, Einsum, EinsumAxes, Symbol};
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 /// This file optimizes tensor contraction order, like Python's opt_einsum
 /// It specifies contraction order using rotating id's, like opt_einsum or numpy,
 /// which is kindof awkward but compatible
@@ -21,6 +20,7 @@ use pyo3::{
     exceptions::PyValueError,
     types::{PyDict, PyList},
 };
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use uuid::Uuid;
 
 use std::{
@@ -46,7 +46,7 @@ pub fn get_disconnected_sugraphs(
 }
 
 pub fn get_int_to_tensor_appearance(tensor_ints: &[Vec<usize>]) -> HashMap<usize, Vec<usize>> {
-    let mut int_to_tensor_appearance: HashMap<usize, Vec<usize>> = HashMap::new();
+    let mut int_to_tensor_appearance: HashMap<usize, Vec<usize>> = HashMap::default();
     for (i, tensor_ints) in tensor_ints.iter().enumerate() {
         for inty in tensor_ints.iter() {
             int_to_tensor_appearance
@@ -262,7 +262,7 @@ impl EinsumSpec {
     }
 
     pub fn normalize(&self) -> EinsumSpec {
-        let mut ints_map: HashMap<usize, usize> = HashMap::new();
+        let mut ints_map: HashMap<usize, usize> = HashMap::default();
         for operand_ints in &self.input_ints {
             for o_int in operand_ints {
                 let z = ints_map.len(); // take length before we borrow as mutable? okay
@@ -363,7 +363,7 @@ impl EinsumSpec {
     #[staticmethod]
     pub fn fancy_string_to_ints(string: String) -> (Vec<EinsumAxes>, EinsumAxes) {
         if let [inputs, output] = string.split("->").collect::<Vec<&str>>()[..] {
-            let mut string_to_int: HashMap<&str, u8> = HashMap::new();
+            let mut string_to_int: HashMap<&str, u8> = HashMap::default();
             let input_ints = inputs
                 .split(',')
                 .map(|string| {
@@ -466,9 +466,9 @@ impl EinsumSpec {
             );
             // unsafe {breakpoint()}
             let mut dp: Vec<HashMap<usize, Rc<DpEntry>>> =
-                (0..sg.len() + 1).map(|_x| HashMap::new()).collect();
-            let mut dominated_sets: HashSet<usize> = HashSet::new();
-            let mut dominated_sets_here: HashSet<usize> = HashSet::new();
+                (0..sg.len() + 1).map(|_x| HashMap::default()).collect();
+            let mut dominated_sets: HashSet<usize> = HashSet::default();
+            let mut dominated_sets_here: HashSet<usize> = HashSet::default();
             dp[1] = sg
                 .iter()
                 .map(|i| {
