@@ -282,34 +282,6 @@ macro_rules! generate_extra_py_ops {
 // add more as needed
 generate_extra_py_ops!(add, getitem, mul);
 
-pub struct PyUuid(pub Uuid);
-
-impl<'source> FromPyObject<'source> for PyUuid {
-    fn extract(uuid_obj: &'source PyAny) -> PyResult<Self> {
-        let uuid_bytes: Vec<u8> =
-            Python::with_gil(|py| PY_UTILS.get_uuid_bytes.call1(py, (uuid_obj,))?.extract(py))?;
-
-        let num_bytes = uuid_bytes.len();
-        let bytes_arr: [u8; 16] = uuid_bytes.try_into().map_err(|_| {
-            PyErr::new::<exceptions::PyTypeError, _>(format!(
-                "expected 16 bytes for uuid, found {}",
-                num_bytes
-            ))
-        })?;
-
-        Ok(PyUuid(Uuid::from_bytes(bytes_arr)))
-    }
-}
-
-impl IntoPy<PyObject> for PyUuid {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        PY_UTILS
-            .construct_uuid_bytes
-            .call1(py, (PyBytes::new(py, &self.0.into_bytes()),))
-            .unwrap()
-    }
-}
-
 #[derive(Debug, Clone)]
 pub struct Tensor {
     tensor: PyObject,
