@@ -1,10 +1,8 @@
 use crate::circuit::EinsumAxes;
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::pyo3_prelude::*;
 use crate::{
     circuit::py_circuit_items::PY_CIRCUIT_ITEMS,
     circuit::HashBytes,
-    smallvec::Sv,
     sv,
     tensor_util::{Shape, TensorInvariantError},
     util::{dict_to_list, filter_out_idx, is_unique, vec_map_insert, AxisInt, ALPHABET},
@@ -14,6 +12,8 @@ use once_cell::sync::Lazy;
 use pyo3::exceptions;
 use pyo3::types::IntoPyDict;
 use regex::Regex;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+use smallvec::SmallVec as Sv;
 use std::{fmt::Debug, iter::zip};
 
 use thiserror::Error;
@@ -397,7 +397,7 @@ impl RearrangeSpec {
 
         if let [input, output] = string.split("->").map(str::trim).collect::<Vec<_>>()[..] {
             let mut sizes: OpShape = sv![];
-            let mut string_to_int: HashMap<String, u8> = HashMap::new();
+            let mut string_to_int: HashMap<String, u8> = HashMap::default();
             let mut f = |s: &str| -> Option<RInts> {
                 let handle_int = |num, sizes: &mut OpShape| {
                     sizes.push(Some(num).into());
@@ -677,7 +677,7 @@ impl RearrangeSpec {
             first_pos
         }
 
-        let mut map: HashMap<AxisInt, AxisInt> = HashMap::new();
+        let mut map: HashMap<AxisInt, AxisInt> = HashMap::default();
         let mut new_int_sizes: OpShape = sv![];
         let mut already_accounted_shape = vec![false; int_sizes.len()];
 
@@ -977,9 +977,9 @@ impl RearrangeSpec {
     pub fn fuse(inner: &Self, outer: &Self) -> Result<Self, RewriteError> {
         let mut inner_sizes: Vec<u64> = inner.get_unwrapped_sizes();
         let mut outer_sizes: Vec<u64> = outer.get_unwrapped_sizes();
-        let mut inner_replaces: HashMap<AxisInt, Vec<AxisInt>> = HashMap::new();
-        let mut outer_replaces: HashMap<AxisInt, Vec<AxisInt>> = HashMap::new();
-        let mut in_to_out: HashMap<AxisInt, AxisInt> = HashMap::new();
+        let mut inner_replaces: HashMap<AxisInt, Vec<AxisInt>> = HashMap::default();
+        let mut outer_replaces: HashMap<AxisInt, Vec<AxisInt>> = HashMap::default();
+        let mut in_to_out: HashMap<AxisInt, AxisInt> = HashMap::default();
 
         // if possible, split up inner.outer_ints and outer.inner_ints until they have the same size for each subdimension (if not possible, raise error)
         for (outer_ints, inner_ints) in izip!(&outer.input_ints, &inner.output_ints) {
