@@ -1,8 +1,6 @@
-use crate::hashmaps::FxHashMap as HashMap;
 use crate::lru_cache::TensorCacheRrfs;
 use crate::py_types::PY_UTILS;
 use crate::rrfs::{save_tensor_rrfs, tensor_from_hash_prefix};
-use crate::smallvec::Sv;
 use crate::util::cumsum;
 use crate::{
     circuit::{CircuitConstructionError, HashBytes},
@@ -18,6 +16,8 @@ use pyo3::{
     types::{PySlice, PyTuple},
     AsPyPointer, FromPyObject, IntoPy, PyAny, PyErr, PyObject, PyResult, Python, ToPyObject,
 };
+use rustc_hash::FxHashMap as HashMap;
+use smallvec::SmallVec as Sv;
 use std::{
     cmp::{max, min},
     fmt::{self, Display},
@@ -381,8 +381,9 @@ impl TensorAxisIndex {
                 .unwrap()
                 .call(py, (seed,), None)
                 .unwrap();
-            let mut kwargs = HashMap::new();
+            let mut kwargs = HashMap::default();
             if let Some(dtype) = device_dtype.dtype {
+                let dtype: &str = &dtype;
                 kwargs.insert("dtype", PY_UTILS.torch.getattr(py, dtype).unwrap());
             }
             if let Some(device) = device_dtype.device {
@@ -834,7 +835,7 @@ impl TorchDeviceDtype {
         })
     }
     pub fn size(&self) -> usize {
-        let map = HashMap::from([
+        let map = HashMap::from_iter([
             ("float32".to_owned(), 4),
             ("float64".to_owned(), 8),
             ("float16".to_owned(), 2),
