@@ -1,7 +1,7 @@
-use crate::{
-    hashmaps::{AHashSet as HashSet, FxHashMap as HashMap},
-    make_lazy,
-};
+use crate::make_lazy;
+use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
+
+use crate::python_println;
 use macro_rules_attribute::apply;
 use once_cell::sync::Lazy;
 
@@ -43,7 +43,7 @@ pub fn is_unique<T: Eq + Hash>(col: &[T]) -> bool {
 }
 
 pub fn unique_to_appearance<T: Eq + Hash + Clone>(vec: &Vec<T>) -> HashMap<T, Vec<usize>> {
-    let mut map: HashMap<T, Vec<usize>> = HashMap::new();
+    let mut map: HashMap<T, Vec<usize>> = HashMap::default();
     for (i, x) in vec.iter().enumerate() {
         map.entry(x.clone()).or_insert(vec![]).push(i);
     }
@@ -69,7 +69,7 @@ pub fn filter_out_idx<T: Clone>(col: &[T], idxs: &HashSet<usize>) -> Vec<T> {
 
 pub fn intersection_all<T: Eq + Hash + Copy>(sets: &Vec<HashSet<T>>) -> HashSet<T> {
     if sets.is_empty() {
-        return HashSet::new();
+        return HashSet::default();
     }
     let (first, rest) = sets.split_first().unwrap();
     rest.iter().fold(first.clone(), |acc, new| {
@@ -136,7 +136,7 @@ macro_rules! timed {
         let result = $x;
 
         let elapsed = timed_macro_now.elapsed();
-        println!("{} took {:.2?}", stringify!($x), elapsed);
+        crate::python_println!("{} took {:.2?}", stringify!($x), elapsed);
         result
     }};
     ($x:expr,$min_to_print_milis:expr,$for_real:expr) => {{
@@ -146,7 +146,7 @@ macro_rules! timed {
 
         let elapsed = timed_macro_now.elapsed();
         if $for_real && elapsed > std::time::Duration::new(0, $min_to_print_milis * 1_000_000) {
-            println!("{} took {:.2?}", stringify!($x), elapsed);
+            crate::python_println!("{} took {:.2?}", stringify!($x), elapsed);
         }
         result
     }};
@@ -314,8 +314,8 @@ pub fn cumsum<T: std::ops::AddAssign + Default + Copy>(col: &[T]) -> Vec<T> {
 pub fn hashmap_collect_except_duplicates<K: Eq + Hash + Clone, V: Eq + Hash + Clone>(
     it: impl Iterator<Item = (K, V)>,
 ) -> HashMap<K, V> {
-    let mut result = HashMap::new();
-    let mut dead: HashSet<K> = HashSet::new();
+    let mut result = HashMap::default();
+    let mut dead: HashSet<K> = HashSet::default();
     for (k, v) in it {
         if !dead.contains(&k) {
             if let Some(old) = result.insert(k.clone(), v.clone()) {
@@ -339,6 +339,19 @@ macro_rules! ss {
     };
 }
 
+/// this exists bc cursed jupyter bug that makes prints from rust hang
+#[macro_export]
+macro_rules! python_println{
+    ($($tt:tt)*)=>{
+        pyo3::Python::with_gil(|py| {
+            py.eval(
+                &format!("print('''{}''')",format!($($tt)*)),
+                None,
+                None,
+            ).unwrap();
+        })
+    }
+}
 trait FromCollect<ItemNew>: FromIterator<ItemNew> {
     fn from_collect(x: impl IntoIterator<Item = impl Into<ItemNew>>) -> Self;
 }
